==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/WorkbookRangeBorder.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "color", 
    "sideIndex", 
    "style", 
    "weight"})
@JsonInclude(Include.NON_NULL)
public class WorkbookRangeBorder extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.workbookRangeBorder";
    }

    @JsonProperty("color")
    protected String color;

    @JsonProperty("sideIndex")
    protected String sideIndex;

    @JsonProperty("style")
    protected String style;

    @JsonProperty("weight")
    protected String weight;

    protected WorkbookRangeBorder() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderWorkbookRangeBorder() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String color;
        private String sideIndex;
        private String style;
        private String weight;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder color(String color) {
            this.color = color;
            this.changedFields = changedFields.add("color");
            return this;
        }

        public Builder sideIndex(String sideIndex) {
            this.sideIndex = sideIndex;
            this.changedFields = changedFields.add("sideIndex");
            return this;
        }

        public Builder style(String style) {
            this.style = style;
            this.changedFields = changedFields.add("style");
            return this;
        }

        public Builder weight(String weight) {
            this.weight = weight;
            this.changedFields = changedFields.add("weight");
            return this;
        }

        public WorkbookRangeBorder build() {
            WorkbookRangeBorder _x = new WorkbookRangeBorder();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.workbookRangeBorder";
            _x.id = id;
            _x.color = color;
            _x.sideIndex = sideIndex;
            _x.style = style;
            _x.weight = weight;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="color")
    @JsonIgnore
    public Optional<String> getColor() {
        return Optional.ofNullable(color);
    }

    public WorkbookRangeBorder withColor(String color) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("color");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.color = color;
        return _x;
    }

    @Property(name="sideIndex")
    @JsonIgnore
    public Optional<String> getSideIndex() {
        return Optional.ofNullable(sideIndex);
    }

    public WorkbookRangeBorder withSideIndex(String sideIndex) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("sideIndex");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.sideIndex = sideIndex;
        return _x;
    }

    @Property(name="style")
    @JsonIgnore
    public Optional<String> getStyle() {
        return Optional.ofNullable(style);
    }

    public WorkbookRangeBorder withStyle(String style) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("style");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.style = style;
        return _x;
    }

    @Property(name="weight")
    @JsonIgnore
    public Optional<String> getWeight() {
        return Optional.ofNullable(weight);
    }

    public WorkbookRangeBorder withWeight(String weight) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("weight");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.weight = weight;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public WorkbookRangeBorder patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public WorkbookRangeBorder put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private WorkbookRangeBorder _copy() {
        WorkbookRangeBorder _x = new WorkbookRangeBorder();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.color = color;
        _x.sideIndex = sideIndex;
        _x.style = style;
        _x.weight = weight;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("WorkbookRangeBorder[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("color=");
        b.append(this.color);
        b.append(", ");
        b.append("sideIndex=");
        b.append(this.sideIndex);
        b.append(", ");
        b.append("style=");
        b.append(this.style);
        b.append(", ");
        b.append("weight=");
        b.append(this.weight);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/WorkbookRangeBorder.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "color", 
    "sideIndex", 
    "style", 
    "weight"})
@JsonInclude(Include.NON_NULL)
public class WorkbookRangeBorder extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.workbookRangeBorder";
    }

    @JsonProperty("color")
    protected String color;

    @JsonProperty("sideIndex")
    protected String sideIndex;

    @JsonProperty("style")
    protected String style;

    @JsonProperty("weight")
    protected String weight;

    protected WorkbookRangeBorder() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderWorkbookRangeBorder() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String color;
        private String sideIndex;
        private String style;
        private String weight;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder color(String color) {
            this.color = color;
            this.changedFields = changedFields.add("color");
            return this;
        }

        public Builder sideIndex(String sideIndex) {
            this.sideIndex = sideIndex;
            this.changedFields = changedFields.add("sideIndex");
            return this;
        }

        public Builder style(String style) {
            this.style = style;
            this.changedFields = changedFields.add("style");
            return this;
        }

        public Builder weight(String weight) {
            this.weight = weight;
            this.changedFields = changedFields.add("weight");
            return this;
        }

        public WorkbookRangeBorder build() {
            WorkbookRangeBorder _x = new WorkbookRangeBorder();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.workbookRangeBorder";
            _x.id = id;
            _x.color = color;
            _x.sideIndex = sideIndex;
            _x.style = style;
            _x.weight = weight;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="color")
    @JsonIgnore
    public Optional<String> getColor() {
        return Optional.ofNullable(color);
    }

    public WorkbookRangeBorder withColor(String color) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("color");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.color = color;
        return _x;
    }

    @Property(name="sideIndex")
    @JsonIgnore
    public Optional<String> getSideIndex() {
        return Optional.ofNullable(sideIndex);
    }

    public WorkbookRangeBorder withSideIndex(String sideIndex) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("sideIndex");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.sideIndex = sideIndex;
        return _x;
    }

    @Property(name="style")
    @JsonIgnore
    public Optional<String> getStyle() {
        return Optional.ofNullable(style);
    }

    public WorkbookRangeBorder withStyle(String style) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("style");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.style = style;
        return _x;
    }

    @Property(name="weight")
    @JsonIgnore
    public Optional<String> getWeight() {
        return Optional.ofNullable(weight);
    }

    public WorkbookRangeBorder withWeight(String weight) {
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = changedFields.add("weight");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.workbookRangeBorder");
        _x.weight = weight;
        return _x;
    }

    public WorkbookRangeBorder withUnmappedField(String name, Object value) {
        WorkbookRangeBorder _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public WorkbookRangeBorder patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public WorkbookRangeBorder put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        WorkbookRangeBorder _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private WorkbookRangeBorder _copy() {
        WorkbookRangeBorder _x = new WorkbookRangeBorder();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.color = color;
        _x.sideIndex = sideIndex;
        _x.style = style;
        _x.weight = weight;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("WorkbookRangeBorder[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("color=");
        b.append(this.color);
        b.append(", ");
        b.append("sideIndex=");
        b.append(this.sideIndex);
        b.append(", ");
        b.append("style=");
        b.append(this.style);
        b.append(", ");
        b.append("weight=");
        b.append(this.weight);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
